@@ -142,10 +142,10 @@ class Road():
             get_attributes()
                 Returns a dictionary of all attributes of the class
 
-            add_successor (element_type,element_id,contact_point,lane_offset)
+            add_successor (element_type,element_id,contact_point,lane_offset,direct_junction)
                 adds a successor for the road
 
-            add_predecessor (element_type,element_id,contact_point,lane_offset)
+            add_predecessor (element_type,element_id,contact_point,lane_offset,direct_junction)
                 adds a predecessor for the road          
 
             add_neighbor (element_type,element_id,direction)
@@ -244,6 +244,8 @@ class Road():
 
             contact_point (ContactPoint): the contact point of the link
 
+            direct_juction (list of int): road id that are successors to this road in a direct junction
+
         """
         if self.successor:
             raise ValueError('only one successor is allowed')
@@ -265,6 +267,8 @@ class Road():
 
             contact_point (ContactPoint): the contact point of the link
 
+            direct_juction (list of int): road id that are predecessors to this road in a direct junction
+
         """
         if self.predecessor:
             raise ValueError('only one predecessor is allowed')
@@ -363,7 +367,7 @@ class Road():
             road_object._update_id()
             self.objects.append(road_object)
             
-    def add_object_roadside(self, road_object_prototype, repeatDistance, sOffset=0, tOffset=0, side=RoadSide.both):
+    def add_object_roadside(self, road_object_prototype, repeatDistance, sOffset=0, tOffset=0, side=RoadSide.both, widthStart=None, widthEnd=None, lengthStart=None, lengthEnd=None, radiusStart=None, radiusEnd=None):
         """ add_object_roadside is a convenience function to add a repeating object on side of the road,
             which can only be used after adjust_roads_and_lanes() has been performed
         
@@ -374,14 +378,31 @@ class Road():
             repeatDistance (float): distance between repeated Objects, 0 for continuous
 
             sOffset (float): start s-coordinate of repeating Objects
-            default: 0
+                Default: 0
             
             tOffset (float): t-offset additional to lane width, sign will be added automatically (i.e. positive if further from roadside)
-            default: 0
+                Default: 0
             
             side (RoadSide): add Objects on both, left or right side 
-            default: both
-        
+                Default: both
+
+            widthStart (float) : width of object at start-coordinate (None follows .osgb)
+                Default: None
+
+            widthEnd (float) : width of object at end-coordinate (if not equal to widthStart, automatic linear width adapted over the distance)
+                Default: None
+
+            lengthStart (float) : length of object at start-coordinate (None follows .osgb)
+                Default: None
+
+            lengthEnd (float) : length of object at end-coordinate (if not equal to lengthStart, automatic linear length adapted over distance)
+                Default: None
+
+            radiusStart (float) : radius of object at start-coordinate (None follows .osgb)
+                Default: None
+
+            radiusEnd (float) : radius of object at end-coordinate (if not equal to radiusStart, automatic linear radius adapted over distance)
+                Default: None
         """
         if not self.planview.adjusted:
             raise RoadsAndLanesNotAdjusted("Could not add roadside object because roads and lanes need to be adjusted first. Consider calling 'adjust_roads_and_lanes()'.")
@@ -412,8 +433,7 @@ class Road():
             road_object.t = (total_widths[idx] + tOffset) * hdg_factors[idx]
             road_object.s = sOffset + s_lanesections[idx]
             road_object.hdg = np.pi * (1 + hdg_factors[idx]) / 2
-            road_object.repeat(self.planview.get_total_length() - sOffset - s_lanesections[idx], repeatDistance)
-        print (repeatDistance)        
+            road_object.repeat(self.planview.get_total_length() - sOffset - s_lanesections[idx], repeatDistance, widthStart=widthStart, widthEnd=widthEnd, lengthStart=lengthStart, lengthEnd=lengthEnd, radiusStart=radiusStart, radiusEnd=radiusEnd)
         self.add_object(road_objects)
 
     def add_signal(self,signal):
@@ -903,4 +923,4 @@ class _Type():
         element = ET.Element('type',attrib=self.get_attributes())
         if self.speed:
             ET.SubElement(element,'speed',attrib={'max':str(self.speed),'unit':self.speed_unit})
-        return element
\ No newline at end of file
+        return element
